==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/comptime/Foreign/calias.scm <==
;* --------------------------------------------------------------------*/
;*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \   /  '                               */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome. Send them to                                          */
;*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
;*-------------------------------------------------------------------- */
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.9/Foreign/calias.scm       */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Jun  6 12:25:42 1996                          */
;*    Last change :  Thu Sep  5 16:39:36 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    The C alias accessors creations.                                 */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module foreign_calias
   (include "Tools/trace.sch")
   (import  type_tools
	    type_type
	    tools_shape
	    foreign_ctype
	    foreign_access))
   
;*---------------------------------------------------------------------*/
;*    make-ctype-accesses! ::calias ...                                */
;*---------------------------------------------------------------------*/
(define-method (make-ctype-accesses! what::calias who::type)
   (trace (expand 3)
	  "make-ctype-accesses(calias): " (shape what) " " (shape who)
	  #\Newline)
   (make-ctype-accesses! (type-alias what) who))

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/comptime/Foreign/calias.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Foreign/calias.scm          */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Thu Jun  6 12:25:42 1996                          */
;*    Last change :  Mon May 15 07:48:06 2000 (serrano)                */
;*    Copyright   :  1996-2000 Manuel Serrano, see LICENSE file        */
;*    -------------------------------------------------------------    */
;*    The C alias accessors creations.                                 */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module foreign_calias
   (include "Tools/trace.sch")
   (import  type_tools
	    type_type
	    tools_shape
	    foreign_ctype
	    foreign_access))
   
;*---------------------------------------------------------------------*/
;*    make-ctype-accesses! ::calias ...                                */
;*---------------------------------------------------------------------*/
(define-method (make-ctype-accesses! what::calias who::type loc)
   (trace (expand 3)
	  "make-ctype-accesses(calias): " (shape what) " " (shape who)
	  #\Newline)
   (make-ctype-accesses! (type-alias what) who loc))
